Config

Struct Config 

pub struct Config { /* private fields */ }

Implementations

Source

impl Config

pub fn reload_env_vars(&self)

Reload the config from all environment variables.

pub fn reload_env_var(&self, var: &str)

Reload a specific environment variable.

pub fn verbose(&self) -> bool

Whether we should do verbose printing.

pub fn warn_unstable(&self) -> bool

Whether we should warn when unstable features are used.

pub fn max_threads(&self) -> usize

The number of threads Polars should ideally use for CPU-intensive work.

pub fn ideal_morsel_size(&self) -> u64

The ideal size of a morsel, in rows.

pub fn engine_affinity(&self) -> Engine

Which engine to use by default.

pub fn parquet_binary_statistics_truncate_length(&self) -> u64

Target byte length to truncate statistics to for binary/string columns in parquet.

pub fn prune_parquet_metadata(&self) -> bool

Whether the optimizer should prune parquet metadata to projected/predicate columns before serializing the IR plan. See parquet_metadata_prune in polars-plan.

pub fn allow_nested_cspe(&self) -> bool

Nested common subplan elimination.

pub fn resolve_metadata_level(&self) -> ResolveMode

How much per-file metadata parquet_file_info resolves at planning time. See ResolveMode for the variants and their cost / IR-shape trade-offs.

pub fn verbose_sensitive(&self) -> bool

Whether we should do verbose printing on sensitive information.

pub fn force_async(&self) -> bool

pub fn import_interval_as_struct(&self) -> bool

pub fn ooc_drift_threshold(&self) -> u64

pub fn ooc_spill_policy(&self) -> SpillPolicy

pub fn ooc_spill_format(&self) -> SpillFormat

pub fn ooc_memory_budget_fraction(&self) -> f64

pub fn ooc_spill_min_bytes(&self) -> u64

pub fn ooc_spill_dir(&self) -> PathBuf

pub fn join_sample_limit(&self) -> u64

pub fn projection_pushdown_prune_strict_hconcat_inputs(&self) -> bool