pub struct Config { /* private fields */ }Implementations
Sourceimpl Config
impl Config
Sourcepub fn reload_env_vars(&self)
pub fn reload_env_vars(&self)
Reload the config from all environment variables.
Sourcepub fn reload_env_var(&self, var: &str)
pub fn reload_env_var(&self, var: &str)
Reload a specific environment variable.
Sourcepub fn warn_unstable(&self) -> bool
pub fn warn_unstable(&self) -> bool
Whether we should warn when unstable features are used.
Sourcepub fn max_threads(&self) -> usize
pub fn max_threads(&self) -> usize
The number of threads Polars should ideally use for CPU-intensive work.
Sourcepub fn ideal_morsel_size(&self) -> u64
pub fn ideal_morsel_size(&self) -> u64
The ideal size of a morsel, in rows.
Sourcepub fn engine_affinity(&self) -> Engine
pub fn engine_affinity(&self) -> Engine
Which engine to use by default.
Sourcepub fn parquet_binary_statistics_truncate_length(&self) -> u64
pub fn parquet_binary_statistics_truncate_length(&self) -> u64
Target byte length to truncate statistics to for binary/string columns in parquet.
Sourcepub fn prune_parquet_metadata(&self) -> bool
pub fn prune_parquet_metadata(&self) -> bool
Whether the optimizer should prune parquet metadata to projected/predicate columns
before serializing the IR plan. See parquet_metadata_prune in polars-plan.
Sourcepub fn allow_nested_cspe(&self) -> bool
pub fn allow_nested_cspe(&self) -> bool
Nested common subplan elimination.
Sourcepub fn resolve_metadata_level(&self) -> ResolveMode
pub fn resolve_metadata_level(&self) -> ResolveMode
How much per-file metadata parquet_file_info resolves at planning
time. See ResolveMode for the variants and their cost / IR-shape
trade-offs.
Sourcepub fn verbose_sensitive(&self) -> bool
pub fn verbose_sensitive(&self) -> bool
Whether we should do verbose printing on sensitive information.